@@ -410,6 +410,8 @@ class intraTADscore(CompartmentPC1):
 
         if useOE == True:
             rawMT = np.nan_to_num(self.matrix)
+            print(rawMT.shape)
+            print(rawMT)
             expectMT = self.makeExpect(rawMT,smooth)
             warnings.filterwarnings("ignore")
             mt = np.nan_to_num(rawMT / expectMT)
